==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Bonvenon @nom@ !',
	'c_accueil_configurer_site' => 'Agordi vian retejon',
	'c_accueil_configurer_site_texte' => 'Unu el la unuaj aferoj por fari estas doni nomon al via retejo.
Ĝi nuntempe nomiĝas « @nom@ ». La retejnomo estas montrita supre de ĉi paĝo.
Klakante sur tio, vi povas ŝanĝi lian nomon, sed ankaŭ donas al ĝi vinjeton kaj devizon.',
	'c_accueil_publication' => 'Publikigu !',
	'c_accueil_publication_texte' => 'Por publikigi paĝon, vi devas krei artikolon.
Por tio, estas necesa krei almenaŭ unu rubrikon. Vi povas fari tion en la menuo « Eldono » per klako sur « Rubrikoj ».',
	'c_accueil_texte' => 'Vi ĵus eniris en la SPIP privata spaco.',
	'c_accueil_texte_revenir' => 'Tiu paĝo prezentas la freŝa ĉefartikola aktiveco en via retejo.
Vi povas reveni al tiu paĝo ĉiumomente klakante la domvigneton,
sur la supra parto, sub via nomo.',
	'c_article_redaction' => 'La artikolo estas redaktata',
	'c_article_redaction_redacteur' => 'La artikolo estas redaktata',
	'c_article_redaction_redacteur_texte' => 'Por proponi vian artikolon al la retej-mastrumantoj kaj al aliaj redakantoj, en la flanka kadro, ŝanĝu « redaktataj » ĝis « proponita por taksado ».
',
	'c_article_redaction_texte' => 'Por proponi ĉi tiun artikolon sur la publika retejo, necesas ŝanĝi ĝian statuton.
En la flanka kadro, ŝanĝu « redaktataj » ĝis « rete publikigita ».',
	'c_articles_creer' => 'Kiel krei artikolon ?',
	'c_articles_creer_texte' => 'Vi povos nur krei artikolon de tiu ĉi paĝo nuntempe existos almenaŭ unu rubrikon en via retejo.
Vi povas krei ĝin de la menuo « Aldono », poste « Rubrikoj ».',
	'c_job' => 'La taksoj por fari…',
	'c_job_texte' => 'Ĉi tiu paĝo listigas venontajn bontenadajn taskojn kiujn SPIP devas realigi.
Tiuj taskoj estas realigitaj je regulaj intervaloj aŭ foje, por pezaj traktadoj petita de kromprogramoj
kiel multaj retpoŝtaj sendoj.',
	'c_rubrique_publier' => 'Kreu artikolon',
	'c_rubrique_publier_texte' => 'Rubriko estas videbla sur la publika spaco nur la momento ke ĝi enhavas almenaŭ unu publikigita enhavo ; ekzemple : publikigita artikolo.
Do kreu artikolon. Vi povas fari tion el ĉi tiu paĝo, sub la priskribo de via rubriko.',
	'c_rubriques_creer' => 'Kreu unuan rubrikon',
	'c_rubriques_creer_texte' => 'La rubrikoj estas la baza strukturo de la retejo ;  vi povos krei artikolojn en ĉiuj rubrikoj.
Komencu krei unuan rubrikon.',
	'c_sites_creer' => 'Kiel krei aŭ importi retejon ?',
	'c_sites_creer_texte' => 'Vi povos krei aŭ importi retejon ĉi tie, nur kiam ekzistos rubriko en via retejo. Vi povas krei tiun rubrikon per la menuo „Eldono“, ero „Rubrikoj“.',

	// E
	'explication_activer_compagnon' => 'La kompano aldonas komentojn en iuj paĝoj de la privata spaco por helpi al unuaj uzadoj de SPIP. Ĉu vi volas ebligi tion ?',
	'explication_reinitialiser_compagnon' => 'La mesaĝoj kiun aŭtoro jam vidis, ne plu estas afiŝita poste.
Ĉu vi volas restarigi tiujn mesaĝojn ?',

	// L
	'label_activer_compagnon' => 'Aktivigu la kompano ?',
	'label_reinitialiser_compagnon' => 'Restarigi la kompan-mesaĝojn',

	// O
	'ok' => 'Konsentite',
	'ok_bien' => 'Bone !',
	'ok_jai_compris' => 'Mi komprenis !',
	'ok_merci' => 'Dankon',
	'ok_parfait' => 'Perfekte !',

	// R
	'reinitialisation' => 'Restarigo',
	'reinitialisation_ok' => 'La restarigo estas farita',
	'reinitialiser' => 'Restarigi',
	'reinitialiser_moi' => 'Jes, nur tiujn kiujn mi legis',
	'reinitialiser_tous' => 'Jes, kiu ajn la aŭtoro ',

	// T
	'titre_compagnon' => 'La kompano',
	'titre_page_configurer_compagnon' => 'Agordi la kompano'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// C
	'c_accueil_bienvenue' => 'Bonvenon @nom@ !',
	'c_accueil_configurer_site' => 'Agordi vian retejon',
	'c_accueil_configurer_site_texte' => 'Unu el la unuaj aferoj por fari estas doni nomon al via retejo.
Ĝi nuntempe nomiĝas « @nom@ ». La retejnomo estas montrita supre de ĉi paĝo.
Klakante sur tio, vi povas ŝanĝi lian nomon, sed ankaŭ donas al ĝi vinjeton kaj devizon.',
	'c_accueil_publication' => 'Publikigu !',
	'c_accueil_publication_texte' => 'Por publikigi paĝon, vi devas krei artikolon.
Por tio, estas necesa krei almenaŭ unu rubrikon. Vi povas fari tion en la menuo « Eldono » per klako sur « Rubrikoj ».',
	'c_accueil_texte' => 'Vi ĵus eniris en la SPIP privata spaco.',
	'c_accueil_texte_revenir' => 'Tiu paĝo prezentas la freŝa ĉefartikola aktiveco en via retejo.
Vi povas reveni al tiu paĝo ĉiumomente klakante la domvigneton,
sur la supra parto, sub via nomo.',
	'c_article_redaction' => 'La artikolo estas redaktata',
	'c_article_redaction_redacteur' => 'La artikolo estas redaktata',
	'c_article_redaction_redacteur_texte' => 'Por proponi vian artikolon al la retej-mastrumantoj kaj al aliaj redakantoj, en la flanka kadro, ŝanĝu « redaktataj » ĝis « proponita por taksado ».
',
	'c_article_redaction_texte' => 'Por proponi ĉi tiun artikolon sur la publika retejo, necesas ŝanĝi ĝian statuton.
En la flanka kadro, ŝanĝu « redaktataj » ĝis « rete publikigita ».',
	'c_articles_creer' => 'Kiel krei artikolon ?',
	'c_articles_creer_texte' => 'Vi povos nur krei artikolon de tiu ĉi paĝo nuntempe existos almenaŭ unu rubrikon en via retejo.
Vi povas krei ĝin de la menuo « Aldono », poste « Rubrikoj ».',
	'c_job' => 'La taksoj por fari…',
	'c_job_texte' => 'Ĉi tiu paĝo listigas venontajn bontenadajn taskojn kiujn SPIP devas realigi.
Tiuj taskoj estas realigitaj je regulaj intervaloj aŭ foje, por pezaj traktadoj petita de kromprogramoj
kiel multaj retpoŝtaj sendoj.',
	'c_rubrique_publier' => 'Kreu artikolon',
	'c_rubrique_publier_texte' => 'Rubriko estas videbla sur la publika spaco nur la momento ke ĝi enhavas almenaŭ unu publikigita enhavo ; ekzemple : publikigita artikolo.
Do kreu artikolon. Vi povas fari tion el ĉi tiu paĝo, sub la priskribo de via rubriko.',
	'c_rubriques_creer' => 'Kreu unuan rubrikon',
	'c_rubriques_creer_texte' => 'La rubrikoj estas la baza strukturo de la retejo ;  vi povos krei artikolojn en ĉiuj rubrikoj.
Komencu krei unuan rubrikon.',
	'c_sites_creer' => 'Kiel krei aŭ importi retejon ?',
	'c_sites_creer_texte' => 'Vi povos krei aŭ importi retejon ĉi tie, nur kiam ekzistos rubriko en via retejo. Vi povas krei tiun rubrikon per la menuo „Eldono“, ero „Rubrikoj“.',

	// E
	'explication_activer_compagnon' => 'La kompano aldonas komentojn en iuj paĝoj de la privata spaco por helpi al unuaj uzadoj de SPIP. Ĉu vi volas ebligi tion ?',
	'explication_reinitialiser_compagnon' => 'La mesaĝoj kiun aŭtoro jam vidis, ne plu estas afiŝita poste.
Ĉu vi volas restarigi tiujn mesaĝojn ?',

	// L
	'label_activer_compagnon' => 'Aktivigu la kompano ?',
	'label_reinitialiser_compagnon' => 'Restarigi la kompan-mesaĝojn',

	// O
	'ok' => 'Konsentite',
	'ok_bien' => 'Bone !',
	'ok_jai_compris' => 'Mi komprenis !',
	'ok_merci' => 'Dankon',
	'ok_parfait' => 'Perfekte !',

	// R
	'reinitialisation' => 'Restarigo',
	'reinitialisation_ok' => 'La restarigo estas farita',
	'reinitialiser' => 'Restarigi',
	'reinitialiser_moi' => 'Jes, nur tiujn kiujn mi legis',
	'reinitialiser_tous' => 'Jes, kiu ajn la aŭtoro ',

	// T
	'titre_compagnon' => 'La kompano',
	'titre_page_configurer_compagnon' => 'Agordi la kompano',
];
